multi\_scale\_expansion package
===============================

Submodules
----------

multi\_scale\_expansion.classification module
---------------------------------------------

.. automodule:: multi_scale_expansion.classification
   :members:
   :undoc-members:
   :show-inheritance:

multi\_scale\_expansion.dataset module
--------------------------------------

.. automodule:: multi_scale_expansion.dataset
   :members:
   :undoc-members:
   :show-inheritance:

multi\_scale\_expansion.model module
------------------------------------

.. automodule:: multi_scale_expansion.model
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: multi_scale_expansion
   :members:
   :undoc-members:
   :show-inheritance:
